CheckboxStates

Struct CheckboxStates 

pub struct CheckboxStates {
    pub choice: usize,
    pub choices: Vec<String>,
    pub selection: Vec<usize>,
}
The state that needs to be kept for Checkbox.

Fields

choice: usize

Current hover option.

choices: Vec<String>

Available choices.

selection: Vec<usize>

Enabled options.

Implementations

Source

impl CheckboxStates

pub fn next_choice(&mut self, rewind: bool)

Move choice index to next choice.

pub fn prev_choice(&mut self, rewind: bool)

Move choice index to previous choice.

pub fn toggle(&mut self)

Check or uncheck the option.

pub fn select(&mut self, i: usize)

Select a specific option.

pub fn has(&self, option: usize) -> bool

Determine if options is toggeled as selected.

pub fn set_choices(&mut self, choices: impl Into<Vec<String>>)

Overwrite the choices available with new ones.

In addition resets current selection and keep index if possible or set it to the first value available.