InputStates

Struct InputStates 

pub struct InputStates {
    pub input: Vec<char>,
    pub cursor: usize,
    pub display_offset: usize,
    pub last_width: Option<u16>,
}
The state that needs to be kept for the Input component.

Fields

input: Vec<char>

The current input text

cursor: usize

The cursor into “input”, used as a index on where a character gets added next

display_offset: usize

The display offset for scrolling, always tries to keep the cursor within bounds

last_width: Option<u16>

The last drawn width of the component that displays “input”.

This is necessary to keep “display_offset” from jumping around on width changes.

Implementations

Source

impl InputStates

pub fn append(&mut self, ch: char, itype: &InputType, max_len: Option<usize>)

Append a character, if possible according to input type.

pub fn backspace(&mut self)

Delete the element at cursor - 1, then decrement cursor by 1.

pub fn delete(&mut self)

Delete element at cursor position.

pub fn incr_cursor(&mut self)

Increment cursor by one if possible. (also known as moving RIGHT)

pub fn decr_cursor(&mut self)

Decrement cursor value by one if possible. (also known as moving LEFT)

pub fn cursor_at_begin(&mut self)

Move the cursor to the beginning of the input.

pub fn cursor_at_end(&mut self)

Move the cursor the the end of the input.

pub fn update_width(&mut self, new_width: u16)

Update the last width used to display InputStates::input.

This is necessary to update InputStates::display_offset correctly and keep it from jumping around on width changes.

Without using this function, no scrolling will effectively be applied.

pub fn render_value(&self, itype: &InputType) -> String

Get the full text to render in the input, according to the InputType.

pub fn render_value_offset(&self, itype: &InputType) -> String

Get the partial text to render, according to the InputType.

Unlike InputStates::render_value, this will only collect the actually displayed text in the returned String.

pub fn render_value_chars(&self, itype: &InputType) -> Vec<char>

Get the characters to render, according to InputType.

It is recommended to use render_value or render_value_offset over this function.

pub fn get_value(&self) -> String

Get the current input as a String in full, without any InputType modifications.

pub fn is_empty(&self) -> bool

Get whether the input is empty or has characters typed.