pub struct TableStates {
pub list_index: usize,
pub list_len: usize,
}Expand description
The state that has to be kept for the Table component.
Fields
list_index: usizeIndex of selected item in textarea
list_len: usizeLines in text area
Implementations
Sourceimpl TableStates
impl TableStates
Sourcepub fn set_list_len(&mut self, len: usize)
pub fn set_list_len(&mut self, len: usize)
Set list length.
Sourcepub fn incr_list_index(&mut self, rewind: bool)
pub fn incr_list_index(&mut self, rewind: bool)
Incremenet list index.
Sourcepub fn decr_list_index(&mut self, rewind: bool)
pub fn decr_list_index(&mut self, rewind: bool)
Decrement list index.
Sourcepub fn fix_list_index(&mut self)
pub fn fix_list_index(&mut self)
Keep index if possible, otherwise set to lenght - 1.
Sourcepub fn list_index_at_first(&mut self)
pub fn list_index_at_first(&mut self)
Set list index to the first item in the list.
Sourcepub fn list_index_at_last(&mut self)
pub fn list_index_at_last(&mut self)
Set list index at the last item of the list.
Sourcepub fn calc_max_step_ahead(&self, max: usize) -> usize
pub fn calc_max_step_ahead(&self, max: usize) -> usize
Calculate the max step ahead to scroll list.
Sourcepub fn calc_max_step_behind(&self, max: usize) -> usize
pub fn calc_max_step_behind(&self, max: usize) -> usize
Calculate the max step ahead to scroll list.