pub struct TextareaStates {
pub list_index: usize,
pub list_len: usize,
}Expand description
The state that has to be kept for the Textarea component.
Fields
list_index: usizeIndex of selected item in textarea
list_len: usizeLines in text area
Implementations
Sourceimpl TextareaStates
impl TextareaStates
Sourcepub fn set_list_len(&mut self, len: usize)
pub fn set_list_len(&mut self, len: usize)
Set list length and fix list index.
Sourcepub fn incr_list_index(&mut self)
pub fn incr_list_index(&mut self)
Incremenet list index.
Sourcepub fn decr_list_index(&mut self)
pub fn decr_list_index(&mut self)
Decrement list index.
Sourcepub fn fix_list_index(&mut self)
pub fn fix_list_index(&mut self)
Keep index if possible, otherwise set to lenght - 1.
Sourcepub fn list_index_at_first(&mut self)
pub fn list_index_at_first(&mut self)
Set list index to the first item in the list.
Sourcepub fn list_index_at_last(&mut self)
pub fn list_index_at_last(&mut self)
Set list index at the last item of the list.