pub struct Canvas { /* private fields */ }Expand description
The Canvas component may be used to draw more detailed figures using braille patterns (each cell can have a braille character in 8 different positions).
Implementations
Sourceimpl Canvas
impl Canvas
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Note that setting this value has no effect.
If you want to set the border color, use borders.
If you want to set some point in the canvas, set it in the data.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn modifiers(self, m: TextModifiers) -> Self
pub fn modifiers(self, m: TextModifiers) -> Self
Set the main text modifiers. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background and modifiers!
Sourcepub fn inactive(self, s: Style) -> Self
pub fn inactive(self, s: Style) -> Self
Set a custom style for the border when the component is unfocused.
Sourcepub fn data(self, data: impl IntoIterator<Item = Shape>) -> Self
pub fn data(self, data: impl IntoIterator<Item = Shape>) -> Self
Set the initial data to display on the Canvas.
Sourcepub fn x_bounds(self, bounds: (f64, f64)) -> Self
pub fn x_bounds(self, bounds: (f64, f64)) -> Self
Those are used to define the viewport of the canvas. Only the points whose coordinates are within the viewport are displayed. When you render the canvas using Frame::render_widget, you give an area to draw the widget to (a Rect) and the crate translates the floating point coordinates to those used by our internal terminal representation.
From https://github.com/fdehau/tui-rs/issues/286, also read Canvas::x_bounds.
Sourcepub fn y_bounds(self, bounds: (f64, f64)) -> Self
pub fn y_bounds(self, bounds: (f64, f64)) -> Self
Those are used to define the viewport of the canvas. Only the points whose coordinates are within the viewport are displayed. When you render the canvas using Frame::render_widget, you give an area to draw the widget to (a Rect) and the crate translates the floating point coordinates to those used by our internal terminal representation.
From https://github.com/fdehau/tui-rs/issues/286, also read Canvas::y_bounds.