Chart

Struct Chart 

pub struct Chart {
    pub states: ChartStates,
    /* private fields */
}
A component to display a chart on a cartesian coordinate system. The chart can work both in “active” and “disabled” mode.

Disabled mode

When in disabled mode, the chart won’t be interactive, so you won’t be able to move through data using keys. If you have more data than the maximum amount of bars that can be displayed, you’ll have to update data to display the remaining entries.

Active mode

While in active mode (default) you can put as many entries as you wish. You can move with Cmd::Move or Cmd::GoTo.

Fields

states: ChartStates

Implementations

Source

impl Chart

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn disabled(self, disabled: bool) -> Self

Set whether this component should appear “disabled” (or also known as “locked”).

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn data(self, data: impl IntoIterator<Item = ChartDataset>) -> Self

Builder-Style function to set the initial data

pub fn x_bounds(self, bounds: (f64, f64)) -> Self

Set the bounds for the X-axis.

pub fn y_bounds(self, bounds: (f64, f64)) -> Self

Set the bounds for the Y-axis.

pub fn x_labels(self, labels: &[&str]) -> Self

Set labels for the X-Axis, see Axis::labels.

pub fn y_labels(self, labels: &[&str]) -> Self

Set labels for the Y-Axis, see Axis::labels.

pub fn x_style(self, s: Style) -> Self

Set a specific style for the X-Axis.

pub fn y_style(self, s: Style) -> Self

Set a specific style for the Y-Axis.

pub fn x_title<S: Into<String>>(self, t: S) -> Self

Give the X axis a title

pub fn y_title<S: Into<String>>(self, t: S) -> Self

Give the Y axis a title