ChartDataset

Struct ChartDataset 

pub struct ChartDataset {
    pub name: LineStatic,
    pub marker: Marker,
    pub graph_type: GraphType,
    pub style: Style,
    /* private fields */
}
Dataset describes a set of data for a chart.

This mainly exists to map to ratatui’s Dataset, which does not allow owned data.

Fields

name: LineStaticmarker: Markergraph_type: GraphTypestyle: Style

Implementations

Source

impl ChartDataset

pub fn name<S: Into<LineStatic>>(self, name: S) -> Self

Set a name for the dataset.

pub fn marker(self, m: Marker) -> Self

Set the Marker type for the dataset.

pub fn graph_type(self, g: GraphType) -> Self

Set the GraphType for the dataset.

pub fn style(self, s: Style) -> Self

Set Style for the dataset.

This style is used for the data points and the legenend (if not overwritten by the text’s style).

Read more in Dataset::style.

pub fn data(self, data: Vec<(f64, f64)>) -> Self

Set the data for this dataset.

pub fn push(&mut self, point: (f64, f64))

Push a new point to the back of this dataset.

pub fn pop(&mut self)

Pop the last point from this dataset.

pub fn pop_front(&mut self)

Pop the first point in this dataset.

pub fn get_data(&self) -> &[(f64, f64)]

Get a reference to the data.

pub fn as_tuichart<'a>(&'a self, start: usize) -> TuiDataset<'a>

Create ratatui Dataset from the current ChartDataset.

Only elements from start are included.