Checkbox

Struct Checkbox 

pub struct Checkbox {
    pub states: CheckboxStates,
    /* private fields */
}
The checkbox component is a multi-choice selector.

Use Radio if a single-choice selector is wanted.

Fields

states: CheckboxStates

Implementations

Source

impl Checkbox

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn highlight_style(self, s: Style) -> Self

Set a custom highlight style that is patched ontop of the normal style.

By default the highlight style is just Style::new().add_modifier(Modifier::REVERSED).

pub fn rewind(self, r: bool) -> Self

Set whether wraparound should be possible (down on the last choice wraps around to 0, and the other way around).

pub fn choices<S: Into<String>>( self, choices: impl IntoIterator<Item = S>, ) -> Self

Set the choices that should be possible.

pub fn values(self, selected: &[usize]) -> Self

Set the initially selected choices.

pub fn always_active(self) -> Self

Set the current component to be always active (show highligh even if unfocused)