pub struct Container {
pub children: Vec<Box<dyn Component>>,
/* private fields */
}Expand description
Container represents an empty container where you can put other components into it.
It will render components based on how you defined the layout.
The way it updates properties is usually by assigning the attributes to all the children components, but
when defining the component you can override these behaviours by implementing attr() yourself and directly accessing children’s attr().
By default it will forward Commands' to all the children and will return a CmdResult::Batch` with all the results.
Fields
children: Vec<Box<dyn Component>>Container children
Implementations
Sourceimpl Container
impl Container
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Set the main foreground color. This may get overwritten by individual text styles.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn modifiers(self, m: TextModifiers) -> Self
pub fn modifiers(self, m: TextModifiers) -> Self
Set the main text modifiers. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background and modifiers!
Sourcepub fn inactive(self, s: Style) -> Self
pub fn inactive(self, s: Style) -> Self
Set a custom style for the border when the component is unfocused.