Gauge

Struct Gauge 

pub struct Gauge { /* private fields */ }
Gauge provides a multi-line component which shows the progress. It is possible to set the style for the progress bar and the text shown above it.

Read more in Gauge.

If only a single-line Gauge is necessary, use LineGauge instead.

Implementations

Source

impl Gauge

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn label<S: Into<String>>(self, s: S) -> Self

Set a label text for the Bar.

pub fn progress(self, p: f64) -> Self

Set the initial progress value.