Input

Struct Input 

pub struct Input {
    pub states: InputStates,
    /* private fields */
}
Input represents a read-write input field. This component supports different input types, input length and handles input events related to cursor position, backspace, canc, …

Fields

states: InputStates

Implementations

Source

impl Input

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn input_type(self, itype: InputType) -> Self

Set the type of input this Input Component is for. Specific types may have different display or validate methods.

pub fn input_len(self, ilen: usize) -> Self

Set the max length of the input.

pub fn value<S: Into<String>>(self, s: S) -> Self

Set the inital value of the Input.

pub fn invalid_style(self, s: Style) -> Self

Set a style for when the input fails validation.

pub fn placeholder<S: Into<LineStatic>>(self, placeholder: S) -> Self

Set a placeholder text for when the Input is empty.