pub struct LineGauge { /* private fields */ }Expand description
Implementations
Sourceimpl LineGauge
impl LineGauge
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Set the main foreground color. This may get overwritten by individual text styles.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn modifiers(self, m: TextModifiers) -> Self
pub fn modifiers(self, m: TextModifiers) -> Self
Set the main text modifiers. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background and modifiers!
Sourcepub fn inactive(self, s: Style) -> Self
pub fn inactive(self, s: Style) -> Self
Set a custom style for the border when the component is unfocused.
Sourcepub fn line_style<F: Into<SpanStatic>, U: Into<SpanStatic>>(
self,
filled: F,
unfilled: U,
) -> Self
pub fn line_style<F: Into<SpanStatic>, U: Into<SpanStatic>>( self, filled: F, unfilled: U, ) -> Self
Set custom Style & Symbols for the filled & unfilled styles.
By default ratatui uses HORIZONTAL for both.