List

Struct List 

pub struct List {
    pub states: ListStates,
    /* private fields */
}
List represents a read-only textual list component which can be scrollable through arrows or inactive.

Fields

states: ListStates

Implementations

Source

impl List

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn rewind(self, r: bool) -> Self

Set whether wraparound should be possible (down on the last choice wraps around to 0, and the other way around).

pub fn step(self, step: usize) -> Self

Set the scroll stepping to use on Cmd::Scroll(Direction::Up) or Cmd::Scroll(Direction::Down).

pub fn scroll(self, scrollable: bool) -> Self

Should the list be scrollable or always show only the top (0th) element?

pub fn highlight_str<S: Into<LineStatic>>(self, s: S) -> Self

Set the Symbol and Style for the indicator of the current line.

pub fn highlight_style(self, s: Style) -> Self

Set a custom highlight style that is patched on-top of the normal style.

By default the highlight style is just Style::new().add_modifier(Modifier::REVERSED).

pub fn highlight_style_inactive(self, s: Style) -> Self

Set a custom highlight style that is patched on-top of the highlight style when unfocused.

pub fn rows<T>(self, rows: impl IntoIterator<Item = T>) -> Self
where T: Into<LineStatic>,

Set the rows of items the list should contain

pub fn selected_line(self, line: usize) -> Self

Set the initially selected line.

pub fn always_active(self) -> Self

Set the current component to be always active (show highligh even if unfocused)