Paragraph

Struct Paragraph 

pub struct Paragraph { /* private fields */ }
A Paragraph represents multi-line, multi-style, automatically wrapped text, with container support.

This component does not scroll. If scrolling is additionally wanted, use Textarea.

If single-style, single-line text is wanted, use Label. If multi-style, single-line text is wanted, use Span.

Implementations

Source

impl Paragraph

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn alignment_horizontal(self, a: HorizontalAlignment) -> Self

Set the horizontal text alignment.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn text<T>(self, text: T) -> Self
where T: Into<TextStatic>,

Set the text of the Paragraph.

pub fn wrap_trim(self, wrap: bool) -> Self

Set wheter automatic wrap whitespace trimming should be enabled.

Default: false