Select

Struct Select 

pub struct Select {
    pub states: SelectStates,
    /* private fields */
}
Select represents a select field, like in HTML. The size for the component must be 3 (border + selected) + the quantity of rows you want to display other options when opened (at least 3).

Similar to Radio, Select is a single-choice selector, but the difference is that it does not show the selector unless the “Tab” is open, and only shows the currently selected choice.

Fields

states: SelectStates

Implementations

Source

impl Select

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn rewind(self, r: bool) -> Self

Set whether wraparound should be possible (down on the last choice wraps around to 0, and the other way around).

pub fn highlight_str<S: Into<LineStatic>>(self, s: S) -> Self

Set the Symbol and Style for the indicator of the current line.

pub fn highlight_style(self, s: Style) -> Self

Set a custom highlight style that is patched ontop of the normal style.

By default the highlight style is just Style::new().add_modifier(Modifier::REVERSED).

pub fn choices<S: Into<String>>( self, choices: impl IntoIterator<Item = S>, ) -> Self

Set the choices that should be possible.

pub fn value(self, i: usize) -> Self

Set the initially selected choice.