Sparkline

Struct Sparkline 

pub struct Sparkline { /* private fields */ }
A sparkline over more lines.

A sparkline can be interpreted as a dense Vertical Bar Chart, without labels for each line.

This can be used for audio-level visualization or a type of history graph (like bandwidth, cpu usage, etc).

Implementations

Source

impl Sparkline

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background!

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn max_entries(self, max: usize) -> Self

Set the max value of the bar.

pub fn data(self, data: &[u64]) -> Self

Set the initial data.