Spinner

Struct Spinner 

pub struct Spinner {
    pub states: SpinnerStates,
    pub view_auto_step: bool,
    /* private fields */
}
A textual spinner which step changes at each view() call (if manual_step is disabled).

Fields

states: SpinnerStatesview_auto_step: bool

Automatically call SpinnerStates::step in view.

This option might be removed in a future major version

Implementations

Source

impl Spinner

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background!

pub fn sequence<S: Into<String>>(self, s: S) -> Self

Set the sequence of characters to step through.

pub fn manual_step(self) -> Self

Disable automatically stepping the sequence in a view call.