Textarea

Struct Textarea 

pub struct Textarea {
    pub states: TextareaStates,
    /* private fields */
}
A Textarea represents multi-line, multi-style, automatically wrapped text, with container and scroll support.

If scroll is not necessary, use Paragrapg instead.

If single-style, single-line text is wanted, use Label. If multi-style, single-line text is wanted, use Span.

Fields

states: TextareaStates

Implementations

Source

impl Textarea

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn step(self, step: usize) -> Self

Set the scroll stepping to use on Cmd::Scroll(Direction::Up) or Cmd::Scroll(Direction::Down).

pub fn highlight_str<S: Into<LineStatic>>(self, s: S) -> Self

Set the Symbol and Style for the indicator of the current line.

pub fn text_rows<T>(self, text: impl IntoIterator<Item = T>) -> Self
where T: Into<LineStatic>,

Set the Text content via a array or iterator.

Example
Textarea::default()
    .text_rows([
        Line::raw("line1"),
        Line::raw("line2")
    ]);
pub fn text(self, text: impl Into<TextStatic>) -> Self

Set the Text content via a single struct.

Example
Textarea::default()
    .text(Line::raw("line"));
Textarea::default()
    .text(Text::raw("another line"));