#[non_exhaustive]pub struct CommonHighlight {
pub style: Style,
pub style_unfocused: Style,
pub symbol: LineStatic,
}Expand description
Prop Store for very common highlight props.
This structure helps to have a common way to handle the “very common” highlight properties, reducing boilerplate and potential mis-matches.
Additionally, using this over Props, saves on indirection and heap-size.
On usage (usually on view), it also saves on unwraps or “defaulting”
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.style: StyleThe main style to patch CommonProps::style with for the currently active element.
style_unfocused: StyleA Style to patch on-top of style when unfocused.
symbol: LineStaticThe symbol to use to indicate the currently selected element.
Implementations
Sourceimpl CommonHighlight
impl CommonHighlight
Sourcepub fn set(&mut self, attr: Attribute, value: AttrValue) -> Option<AttrValue>
pub fn set(&mut self, attr: Attribute, value: AttrValue) -> Option<AttrValue>
Try to set a given Attribute. Returns Some if the value is unhandled. None if handled.
Sourcepub fn get<'a>(&'a self, attr: Attribute) -> Option<AttrValueRef<'a>>
pub fn get<'a>(&'a self, attr: Attribute) -> Option<AttrValueRef<'a>>
Try to get a given Attribute.
Sourcepub fn get_for_query<'a>(&'a self, attr: Attribute) -> Option<QueryResult<'a>>
pub fn get_for_query<'a>(&'a self, attr: Attribute) -> Option<QueryResult<'a>>
Try to get a given Attribute as a type compatible with Component::query.
Sourcepub fn get_symbol(&self) -> Option<Line<'_>>
pub fn get_symbol(&self) -> Option<Line<'_>>
Get the set highlight symbol as its own Line instance, but referencing the existing data.
Sourcepub fn get_style_focus(&self, normal_style: Style, focus: bool) -> Style
pub fn get_style_focus(&self, normal_style: Style, focus: bool) -> Style
Get the patched highlight style with focused or unfocused style.