#[non_exhaustive]pub struct CommonProps {
pub style: Style,
pub border_unfocused_style: Style,
pub border: Option<Borders>,
pub title: Option<Title>,
pub display: bool,
pub focused: bool,
pub always_active: bool,
}Expand description
Prop Store for very common props.
This structure helps to have a common way to handle the “very common” properties, reducing boilerplate and potential mis-matches.
Additionally, using this over Props, saves on indirection and heap-size.
On usage (usually on view), it also saves on unwraps or “defaulting”.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.style: StyleThe main and common style for a given widget. This is mostly used unless overwritten by more specific styles.
border_unfocused_style: StyleSet a different style for the border when the current component is unfocused. This will effectively be merged with style.
border: Option<Borders>A Border to apply, if set.
title: Option<Title>The title for the Border.
display: boolDetermines if the current component should be drawn at all.
focused: boolDetermines if the current component is focused or not.
always_active: boolDetermines if the current component should always use the “active” style, regardless if it is focused or not.
Implementations
Sourceimpl CommonProps
impl CommonProps
Sourcepub fn set(&mut self, attr: Attribute, value: AttrValue) -> Option<AttrValue>
pub fn set(&mut self, attr: Attribute, value: AttrValue) -> Option<AttrValue>
Try to set a given Attribute. Returns Some if the value is unhandled. None if handled.
Sourcepub fn get<'a>(&'a self, attr: Attribute) -> Option<AttrValueRef<'a>>
pub fn get<'a>(&'a self, attr: Attribute) -> Option<AttrValueRef<'a>>
Try to get a given Attribute.
Sourcepub fn get_for_query<'a>(&'a self, attr: Attribute) -> Option<QueryResult<'a>>
pub fn get_for_query<'a>(&'a self, attr: Attribute) -> Option<QueryResult<'a>>
Try to get a given Attribute as a type compatible with Component::query.