Module components

Module components 

All components and their extra properties and state.

Modules

props
Custom properties for stdlib components.
states
This module exposes all *State structs for all components.

Structs

BarChart
A component to display a chart with bars. The bar chart can work both in “active” and “disabled” mode.
Canvas
The Canvas component may be used to draw more detailed figures using braille patterns (each cell can have a braille character in 8 different positions).
Chart
A component to display a chart on a cartesian coordinate system. The chart can work both in “active” and “disabled” mode.
ChartDataset
Dataset describes a set of data for a chart.
Checkbox
The checkbox component is a multi-choice selector.
Container
Container represents an empty container where you can put other components into it.
Gauge
Gauge provides a multi-line component which shows the progress. It is possible to set the style for the progress bar and the text shown above it.
Input
Input represents a read-write input field. This component supports different input types, input length and handles input events related to cursor position, backspace, canc, …
Label
A Label. It represents a single-line, single-style text without any container support.
LineGauge
LineGauge, also known as progress bars, provides a component which shows a line which is some percent filled.
List
List represents a read-only textual list component which can be scrollable through arrows or inactive.
Paragraph
A Paragraph represents multi-line, multi-style, automatically wrapped text, with container support.
Phantom
Phantom is a component which is not rendered. It’s only purpose is to become a global listener in a tui-realm application for some kind of events using subscriptions.
Radio
The radio component is a single-choice selector.
Select
Select represents a select field, like in HTML. The size for the component must be 3 (border + selected) + the quantity of rows you want to display other options when opened (at least 3).
Span
A Span represents single-line, multi-style text, without any container support.
Sparkline
A sparkline over more lines.
Spinner
A textual spinner which step changes at each view() call (if manual_step is disabled).
Table
Table represents a read-only textual table component which can be scrollable through arrows or inactive.
Textarea
A Textarea represents multi-line, multi-style, automatically wrapped text, with container and scroll support.