pub struct CheckboxStates {
pub choice: usize,
pub choices: Vec<String>,
pub selection: Vec<usize>,
}Expand description
The state that needs to be kept for Checkbox.
Fields
choice: usizeCurrent hover option.
choices: Vec<String>Available choices.
selection: Vec<usize>Enabled options.
Implementations
Sourceimpl CheckboxStates
impl CheckboxStates
Sourcepub fn next_choice(&mut self, rewind: bool)
pub fn next_choice(&mut self, rewind: bool)
Move choice index to next choice.
Sourcepub fn prev_choice(&mut self, rewind: bool)
pub fn prev_choice(&mut self, rewind: bool)
Move choice index to previous choice.
Sourcepub fn set_choices(&mut self, choices: impl Into<Vec<String>>)
pub fn set_choices(&mut self, choices: impl Into<Vec<String>>)
Overwrite the choices available with new ones.
In addition resets current selection and keep index if possible or set it to the first value available.