pub struct BarChart {
pub states: BarChartStates,
/* private fields */
}Expand description
A component to display a chart with bars. The bar chart can work both in “active” and “disabled” mode.
Disabled mode
When in disabled mode, the chart won’t be interactive, so you won’t be able to move through data using keys. If you have more data than the maximum amount of bars that can be displayed, you’ll have to update data to display the remaining entries.
Active mode
While in active mode (default) you can put as many entries as you wish. You can move with Cmd::Move or Cmd::GoTo.
Fields
states: BarChartStatesImplementations
Sourceimpl BarChart
impl BarChart
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Set the main foreground color. This may get overwritten by individual text styles.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn modifiers(self, m: TextModifiers) -> Self
pub fn modifiers(self, m: TextModifiers) -> Self
Set the main text modifiers. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background and modifiers!
Sourcepub fn disabled(self, disabled: bool) -> Self
pub fn disabled(self, disabled: bool) -> Self
Set whether this component should appear “disabled” (or also known as “locked”).
Sourcepub fn inactive(self, s: Style) -> Self
pub fn inactive(self, s: Style) -> Self
Set a custom style for the border when the component is unfocused.
Sourcepub fn bar_gap(self, gap: u16) -> Self
pub fn bar_gap(self, gap: u16) -> Self
Set a custom gap between bars, see BarChart::bar_gap.
Sourcepub fn label_style(self, s: Style) -> Self
pub fn label_style(self, s: Style) -> Self
Set a custom style for all bar labels.
Sourcepub fn max_bars(self, l: usize) -> Self
pub fn max_bars(self, l: usize) -> Self
Set the max amount of bars to display.
By default the data length.
Sourcepub fn value_style(self, s: Style) -> Self
pub fn value_style(self, s: Style) -> Self
Set a custom style for all values.