pub struct ChartDataset {
pub name: LineStatic,
pub marker: Marker,
pub graph_type: GraphType,
pub style: Style,
/* private fields */
}Expand description
Dataset describes a set of data for a chart.
This mainly exists to map to ratatui’s Dataset, which does not allow owned data.
Fields
name: LineStaticmarker: Markergraph_type: GraphTypestyle: StyleImplementations
Sourceimpl ChartDataset
impl ChartDataset
Sourcepub fn name<S: Into<LineStatic>>(self, name: S) -> Self
pub fn name<S: Into<LineStatic>>(self, name: S) -> Self
Set a name for the dataset.
Sourcepub fn graph_type(self, g: GraphType) -> Self
pub fn graph_type(self, g: GraphType) -> Self
Set the GraphType for the dataset.
Sourcepub fn style(self, s: Style) -> Self
pub fn style(self, s: Style) -> Self
Set Style for the dataset.
This style is used for the data points and the legenend (if not overwritten by the text’s style).
Read more in Dataset::style.
Sourcepub fn as_tuichart<'a>(&'a self, start: usize) -> TuiDataset<'a>
pub fn as_tuichart<'a>(&'a self, start: usize) -> TuiDataset<'a>
Create ratatui Dataset from the current ChartDataset.
Only elements from start are included.