Container

Struct Container 

pub struct Container {
    pub children: Vec<Box<dyn Component>>,
    /* private fields */
}
Container represents an empty container where you can put other components into it.

It will render components based on how you defined the layout. The way it updates properties is usually by assigning the attributes to all the children components, but when defining the component you can override these behaviours by implementing attr() yourself and directly accessing children’s attr(). By default it will forward Commands' to all the children and will return a CmdResult::Batch` with all the results.

Fields

children: Vec<Box<dyn Component>>

Container children

Implementations

Source

impl Container

pub fn foreground(self, fg: Color) -> Self

Set the main foreground color. This may get overwritten by individual text styles.

pub fn background(self, bg: Color) -> Self

Set the main background color. This may get overwritten by individual text styles.

pub fn modifiers(self, m: TextModifiers) -> Self

Set the main text modifiers. This may get overwritten by individual text styles.

pub fn style(self, style: Style) -> Self

Set the main style. This may get overwritten by individual text styles.

This option will overwrite any previous foreground, background and modifiers!

pub fn inactive(self, s: Style) -> Self

Set a custom style for the border when the component is unfocused.

pub fn borders(self, b: Borders) -> Self

Add a border to the component.

pub fn title<T: Into<Title>>(self, title: T) -> Self

Add a title to the component.

pub fn layout(self, layout: Layout) -> Self

Set a ratatui Layout to use for all the child components.

If this is unset, nothing gets drawn!

pub fn children(self, children: Vec<Box<dyn Component>>) -> Self

Set the children Components this container contains.