pub struct List {
pub states: ListStates,
/* private fields */
}Expand description
List represents a read-only textual list component which can be scrollable through arrows or inactive.
Fields
states: ListStatesImplementations
Sourceimpl List
impl List
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Set the main foreground color. This may get overwritten by individual text styles.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn modifiers(self, m: TextModifiers) -> Self
pub fn modifiers(self, m: TextModifiers) -> Self
Set the main text modifiers. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background and modifiers!
Sourcepub fn inactive(self, s: Style) -> Self
pub fn inactive(self, s: Style) -> Self
Set a custom style for the border when the component is unfocused.
Sourcepub fn rewind(self, r: bool) -> Self
pub fn rewind(self, r: bool) -> Self
Set whether wraparound should be possible (down on the last choice wraps around to 0, and the other way around).
Sourcepub fn step(self, step: usize) -> Self
pub fn step(self, step: usize) -> Self
Set the scroll stepping to use on Cmd::Scroll(Direction::Up) or Cmd::Scroll(Direction::Down).
Sourcepub fn scroll(self, scrollable: bool) -> Self
pub fn scroll(self, scrollable: bool) -> Self
Should the list be scrollable or always show only the top (0th) element?
Sourcepub fn highlight_str<S: Into<LineStatic>>(self, s: S) -> Self
pub fn highlight_str<S: Into<LineStatic>>(self, s: S) -> Self
Set the Symbol and Style for the indicator of the current line.
Sourcepub fn highlight_style(self, s: Style) -> Self
pub fn highlight_style(self, s: Style) -> Self
Set a custom highlight style that is patched on-top of the normal style.
By default the highlight style is just Style::new().add_modifier(Modifier::REVERSED).
Sourcepub fn highlight_style_inactive(self, s: Style) -> Self
pub fn highlight_style_inactive(self, s: Style) -> Self
Set a custom highlight style that is patched on-top of the highlight style when unfocused.
Sourcepub fn rows<T>(self, rows: impl IntoIterator<Item = T>) -> Selfwhere
T: Into<LineStatic>,
pub fn rows<T>(self, rows: impl IntoIterator<Item = T>) -> Selfwhere
T: Into<LineStatic>,
Set the rows of items the list should contain
Sourcepub fn selected_line(self, line: usize) -> Self
pub fn selected_line(self, line: usize) -> Self
Set the initially selected line.
Sourcepub fn always_active(self) -> Self
pub fn always_active(self) -> Self
Set the current component to be always active (show highligh even if unfocused)