pub struct Radio {
pub states: RadioStates,
/* private fields */
}Expand description
The radio component is a single-choice selector.
Use Checkbox if a multi-choice selector is wanted.
Fields
states: RadioStatesImplementations
Sourceimpl Radio
impl Radio
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Set the main foreground color. This may get overwritten by individual text styles.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn modifiers(self, m: TextModifiers) -> Self
pub fn modifiers(self, m: TextModifiers) -> Self
Set the main text modifiers. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background and modifiers!
Sourcepub fn inactive(self, s: Style) -> Self
pub fn inactive(self, s: Style) -> Self
Set a custom style for the border when the component is unfocused.
Sourcepub fn highlight_style(self, s: Style) -> Self
pub fn highlight_style(self, s: Style) -> Self
Set a custom highlight style that is patched ontop of the normal style.
By default the highlight style is just Style::new().add_modifier(Modifier::REVERSED).
Sourcepub fn rewind(self, r: bool) -> Self
pub fn rewind(self, r: bool) -> Self
Set whether wraparound should be possible (down on the last choice wraps around to 0, and the other way around).
Sourcepub fn choices<S: Into<String>>(
self,
choices: impl IntoIterator<Item = S>,
) -> Self
pub fn choices<S: Into<String>>( self, choices: impl IntoIterator<Item = S>, ) -> Self
Set the choices that should be possible.
Sourcepub fn always_active(self) -> Self
pub fn always_active(self) -> Self
Set the current component to be always active (show highligh even if unfocused)