pub struct Sparkline { /* private fields */ }Expand description
A sparkline over more lines.
A sparkline can be interpreted as a dense Vertical Bar Chart, without labels for each line.
This can be used for audio-level visualization or a type of history graph (like bandwidth, cpu usage, etc).
Implementations
Sourceimpl Sparkline
impl Sparkline
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Set the main foreground color. This may get overwritten by individual text styles.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background!
Sourcepub fn inactive(self, s: Style) -> Self
pub fn inactive(self, s: Style) -> Self
Set a custom style for the border when the component is unfocused.
Sourcepub fn max_entries(self, max: usize) -> Self
pub fn max_entries(self, max: usize) -> Self
Set the max value of the bar.