pub struct Spinner {
pub states: SpinnerStates,
pub view_auto_step: bool,
/* private fields */
}Expand description
A textual spinner which step changes at each view() call (if manual_step is disabled).
Fields
states: SpinnerStatesview_auto_step: boolAutomatically call SpinnerStates::step in view.
This option might be removed in a future major version
Implementations
Sourceimpl Spinner
impl Spinner
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Set the main foreground color. This may get overwritten by individual text styles.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background!
Sourcepub fn sequence<S: Into<String>>(self, s: S) -> Self
pub fn sequence<S: Into<String>>(self, s: S) -> Self
Set the sequence of characters to step through.
Sourcepub fn manual_step(self) -> Self
pub fn manual_step(self) -> Self
Disable automatically stepping the sequence in a view call.