pub struct Textarea {
pub states: TextareaStates,
/* private fields */
}Expand description
Fields
states: TextareaStatesImplementations
Sourceimpl Textarea
impl Textarea
Sourcepub fn foreground(self, fg: Color) -> Self
pub fn foreground(self, fg: Color) -> Self
Set the main foreground color. This may get overwritten by individual text styles.
Sourcepub fn background(self, bg: Color) -> Self
pub fn background(self, bg: Color) -> Self
Set the main background color. This may get overwritten by individual text styles.
Sourcepub fn modifiers(self, m: TextModifiers) -> Self
pub fn modifiers(self, m: TextModifiers) -> Self
Set the main text modifiers. This may get overwritten by individual text styles.
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the main style. This may get overwritten by individual text styles.
This option will overwrite any previous foreground, background and modifiers!
Sourcepub fn inactive(self, s: Style) -> Self
pub fn inactive(self, s: Style) -> Self
Set a custom style for the border when the component is unfocused.
Sourcepub fn step(self, step: usize) -> Self
pub fn step(self, step: usize) -> Self
Set the scroll stepping to use on Cmd::Scroll(Direction::Up) or Cmd::Scroll(Direction::Down).
Sourcepub fn highlight_str<S: Into<LineStatic>>(self, s: S) -> Self
pub fn highlight_str<S: Into<LineStatic>>(self, s: S) -> Self
Set the Symbol and Style for the indicator of the current line.
Sourcepub fn text_rows<T>(self, text: impl IntoIterator<Item = T>) -> Selfwhere
T: Into<LineStatic>,
pub fn text_rows<T>(self, text: impl IntoIterator<Item = T>) -> Selfwhere
T: Into<LineStatic>,
Set the Text content via a array or iterator.
Example
Sourcepub fn text(self, text: impl Into<TextStatic>) -> Self
pub fn text(self, text: impl Into<TextStatic>) -> Self
Set the Text content via a single struct.
Example