CommonHighlight

Struct CommonHighlight 

#[non_exhaustive]
pub struct CommonHighlight { pub style: Style, pub symbol: LineStatic, }
Prop Store for very common highlight props.

This structure helps to have a common way to handle the “very common” highlight properties, reducing boilerplate and potential mis-matches.

Additionally, using this over Props, saves on indirection and heap-size. On usage (usually on view), it also saves on unwraps or “defaulting”

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
style: Style

The main style to patch CommonProps::style with for the currently active element.

symbol: LineStatic

The symbol to use to indicate the currently selected element.

Implementations

Source

impl CommonHighlight

pub fn set(&mut self, attr: Attribute, value: AttrValue) -> Option<AttrValue>

Try to set a given Attribute. Returns Some if the value is unhandled. None if handled.

pub fn get<'a>(&'a self, attr: Attribute) -> Option<AttrValueRef<'a>>

Try to get a given Attribute.

pub fn get_for_query<'a>(&'a self, attr: Attribute) -> Option<QueryResult<'a>>

Try to get a given Attribute as a type compatible with Component::query.

pub fn get_symbol(&self) -> Option<Line<'_>>

pub fn get_style(&self, normal_style: Style) -> Style