CommonProps

Struct CommonProps 

#[non_exhaustive]
pub struct CommonProps { pub style: Style, pub border_unfocused_style: Style, pub border: Option<Borders>, pub title: Option<Title>, pub display: bool, pub focused: bool, pub always_active: bool, }
Prop Store for very common props.

This structure helps to have a common way to handle the “very common” properties, reducing boilerplate and potential mis-matches.

Additionally, using this over Props, saves on indirection and heap-size. On usage (usually on view), it also saves on unwraps or “defaulting”.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
style: Style

The main and common style for a given widget. This is mostly used unless overwritten by more specific styles.

border_unfocused_style: Style

Set a different style for the border when the current component is unfocused. This will effectively be merged with style.

border: Option<Borders>

A Border to apply, if set.

title: Option<Title>

The title for the Border.

display: bool

Determines if the current component should be drawn at all.

focused: bool

Determines if the current component is focused or not.

always_active: bool

Determines if the current component should always use the “active” style, regardless if it is focused or not.

Implementations

Source

impl CommonProps

pub fn set(&mut self, attr: Attribute, value: AttrValue) -> Option<AttrValue>

Try to set a given Attribute. Returns Some if the value is unhandled. None if handled.

pub fn get<'a>(&'a self, attr: Attribute) -> Option<AttrValueRef<'a>>

Try to get a given Attribute.

pub fn get_for_query<'a>(&'a self, attr: Attribute) -> Option<QueryResult<'a>>

Try to get a given Attribute as a type compatible with Component::query.

pub fn get_block(&self) -> Option<Block<'_>>

Get a Block with the configuration from the common props, if borders are defined.

Uses get_block.

pub fn is_active(&self) -> bool

Get if the current component is determined to be “active”, either by having “Always active” active or being focused.